//   Copyright 2021 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

#include "Display_a_scene.h"
#include "ArcGISRuntimeEnvironment.h"
#include "ArcGISTiledElevationSource.h"
#include "Scene.h"
#include "SceneQuickView.h"

#include <QUrl>

using namespace Esri::ArcGISRuntime;
Display_a_scene::Display_a_scene(QObject* parent /* = nullptr */):

    QObject(parent)

{
    setupScene();
}

Display_a_scene::~Display_a_scene()
{
}

SceneQuickView* Display_a_scene::sceneView() const
{
    return m_sceneView;
}

// Set the view (created in QML)
void Display_a_scene::setSceneView(SceneQuickView* sceneView)
{
    if (!sceneView || sceneView == m_sceneView)
    {
        return;
    }
    m_sceneView = sceneView;
    m_sceneView->setArcGISScene(m_scene);

    emit sceneViewChanged();
}

void Display_a_scene::setupScene()
{

    // Create an item_id to reference an item at a web server
    const QString item_id("579f97b2f3b94d4a8e48a5f140a6639b");
    // Create a QUrl from the web scene server URL and the item_id
    const QUrl portal_url(QString("https://arcgis.com/sharing/rest/content/items/" + item_id));

    // Create the scene, referencing the QUrl
    m_scene = new Scene(portal_url, this);

}

